@@ -29,7 +29,15 @@ extern "C" {
 
 DIR *opendir(const char *);
 int closedir(DIR *);
+#ifdef __dirent_h_recursive
+// Some operating systems we won't mention (such as the imitation
+// of Unix marketed by IBM) implement dirent.h by including sys/dir.h,
+// in which case sys/dir.h defines struct dirent, rather than
+// the struct direct originally used by BSD.
+struct dirent *readdir(DIR *);
+#else
 struct direct *readdir(DIR *);
+#endif
 long telldir(DIR *);
 void seekdir(DIR *, long);
 #ifndef rewinddir
