@@ -27,7 +27,7 @@
 #define _isatty(fd) isatty(fd)
 
 extern int __cvt_double(double number, register int prec, int flags,
-			char *signp, int fmtch, char *startp, char *endp);
+			int *signp, int fmtch, char *startp, char *endp);
 
 /*#define USE_MALLOC_BUF*/
 
@@ -38,3 +38,26 @@ extern int __cvt_double(double number, register int prec, int flags,
 #define ALLOC_BUF(size) (char*)malloc(size)
 #define FREE_BUF(ptr) free(ptr)
 #endif
+
+#define USE_DTOA
+
+// Advantages:
+// - Input gets closest value
+// - Output emits string that when read yields identical value.
+// - Handles Infinity and NaNs (but not re-readable).
+// Disadvantages of dtoa:
+// - May not work for all double formats.
+// - Big chunck of code.
+// - Not reentrant - uses atatic variables freelist,
+//   result, result_k in dtoa
+//   (plus initializes p5s, HOWORD, and LOWORD).
+
+#ifdef USE_DTOA
+extern "C" double strtod(const char *s00, char **se);
+extern "C" char *dtoa(double d, int mode, int ndigits,
+                        int *decpt, int *sign, char **rve);
+extern int __outfloat(double value, streambuf *sb, char mode,
+	       int width, int precision, __fmtflags flags,
+	       char sign_mode, char fill);
+#endif
+
