@@ -106,14 +106,12 @@ extern "C" {
 
 extern void clearerr _ARGS((FILE*));
 extern int fclose _ARGS((FILE*));
-extern FILE *fdopen _ARGS((int, const char *));
 extern int feof _ARGS((FILE*));
 extern int ferror _ARGS((FILE*));
 extern int fflush _ARGS((FILE*));
 extern int fgetc _ARGS((FILE *));
 extern int fgetpos _ARGS((FILE* fp, fpos_t *pos));
 extern char* fgets _ARGS((char*, int, FILE*));
-extern int fileno _ARGS((FILE*));
 extern FILE* fopen _ARGS((const char*, const char*));
 extern int fprintf _ARGS((FILE*, const char* format, ...));
 extern int fputc _ARGS((int, FILE*));
@@ -146,13 +144,15 @@ extern int vfprintf _ARGS((FILE *fp, char const *fmt0, _G_va_list));
 extern int vprintf _ARGS((char const *fmt, _G_va_list));
 extern int vsprintf _ARGS((char* string, const char* format, _G_va_list));
 
-#ifdef _POSIX_SOURCE
+#if !defined(__STRICT_ANSI__) || defined(_POSIX_SOURCE)
+extern FILE *fdopen _ARGS((int, const char *));
+extern int fileno _ARGS((FILE*));
 extern FILE* popen _ARGS((const char*, const char*));
 extern int pclose _ARGS((FILE*));
 #endif
 
-extern int __underflow(struct streambuf*);
-extern int __overflow(struct streambuf*, int);
+extern int __underflow _ARGS((struct streambuf*));
+extern int __overflow _ARGS((struct streambuf*, int));
 
 #ifdef __cplusplus
 }
