@@ -48,14 +48,15 @@ typedef _G_off_t streamoff;
 typedef _G_off_t streampos; // Should perhaps be _G_fpos_t ?
 
 typedef unsigned long __fmtflags;
+typedef unsigned char __iostate;
 
 struct _ios_fields { // The data members of an ios.
     streambuf *_strbuf;
     ostream* _tie;
     int _width;
-    unsigned long _flags;
+    __fmtflags _flags;
     char _fill;
-    __fmtflags _state;
+    __iostate _state;
     unsigned short _precision;
 };
 
@@ -88,6 +89,7 @@ enum open_mode {
 class ios : public _ios_fields {
   public:
     typedef __fmtflags fmtflags;
+    typedef __iostate iostate;
     enum io_state {
 	goodbit = _IOS_GOOD,
 	eofbit = _IOS_EOF,
@@ -106,7 +108,7 @@ class ios : public _ios_fields {
 	   dec=020, oct=040, hex=0100,
 	   showbase=0200, showpoint=0400, uppercase=01000, showpos=02000,
 	   scientific=04000, fixed=0100000, unitbuf=020000, stdio=040000,
-	   dont_close=0x80000000 //Don't close streambuf when destroying stream
+	   dont_close=0x80000000 //Don't delete streambuf on stream destruction
 	   };
 
     ostream* tie() const { return _tie; }
@@ -139,14 +141,14 @@ class ios : public _ios_fields {
     static const unsigned long floatfield;
 
     streambuf* rdbuf() const { return _strbuf; }
-    void clear(int state = 0) { _state = state; }
-    void set(int flag) { _state |= flag; } // In ANSI but not AT&T.
+    void clear(iostate state = 0) { _state = state; }
+    void set(iostate flag) { _state |= flag; } // In ANSI but not AT&T.
     int good() const { return _state == 0; }
     int eof() const { return _state & ios::eofbit; }
     int fail() const { return _state & (ios::badbit|ios::failbit); }
     int bad() const { return _state & ios::badbit; }
     int rdstate() const { return _state; }
-    operator void*() const { return fail() ? (void*)0 : (void*)this; }
+    operator void*() const { return fail() ? (void*)0 : (void*)(-1); }
     int operator!() const { return fail(); }
 
 #ifdef _STREAM_COMPAT
@@ -158,8 +160,8 @@ class ios : public _ios_fields {
 #endif
 
   protected:
-    ios(streambuf*sb) { _strbuf=sb; _state=0; _width=0; _fill=' ';
-			_flags=ios::skipws; _precision=6; }
+    ios(streambuf* sb = 0, ostream* tie = 0);
+    ~ios();
 };
 
 #if __GNUG__==1
@@ -335,6 +337,7 @@ struct streambuf : private __streambuf {
     int in_avail() { return _egptr - _gptr; }
     int out_waiting() { return _pptr - _pbase; }
     virtual int sputn(const char* s, int n);
+    int padn(char pad, int n); // Emit 'n' copies of 'pad'.
     virtual int sgetn(char* s, int n);
     int ignore(int);
     virtual int get_column();
@@ -353,7 +356,7 @@ struct streambuf : private __streambuf {
 	if (_pptr >= _epptr) return __overflow(this, (unsigned char)c);
 	return *_pptr++ = c, (unsigned char)c; }
     void stossc() { if (_gptr < _egptr) _gptr++; }
-    int vscan(char const *fmt0, _G_va_list ap);
+    int vscan(char const *fmt0, _G_va_list ap, ios::iostate* = NULL);
     int vform(char const *fmt0, _G_va_list ap);
 #if 0 /* Work in progress */
     int collumn();  // Current collumn number (of put pointer). -1 is unknown.
@@ -414,7 +417,8 @@ class filebuf : public backupbuf {
     char* cur_ptr() { return is_reading() ?  gptr() : pptr(); }
     /* System's idea of pointer */
     char* file_ptr() { return eGptr(); }
-    int do_flush();
+    int do_write(const char *data, int to_do);
+    int do_flush() { return do_write(_pbase, _pptr-_pbase); }
     // Low-level operations (Usually invoke system calls.)
     virtual _G_ssize_t sys_read(char* buf, _G_size_t size);
     virtual fpos_t sys_seek(fpos_t, _seek_dir);
@@ -429,5 +433,10 @@ inline int ios::writable() { return !(rdbuf()->_flags & _S_NO_WRITES); }
 inline int ios::is_open() { return (rdbuf()->_flags & _S_NO_READS+_S_NO_WRITES)
 				!= _S_NO_READS+_S_NO_WRITES; }
 #endif
+inline ios::ios(streambuf* sb /* = 0 */, ostream* tie /* = 0 */) {
+		_tie = tie; _strbuf=sb; _state=0; _width=0; _fill=' ';
+		_flags=ios::skipws; _precision=6; }
+inline ios::~ios() {
+    if (!(_flags & (unsigned int)ios::dont_close)) delete _strbuf; }
 
 #endif /* _STREAMBUF_H */
