@@ -24,9 +24,9 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #define _BitString_h 1
 
 #include <stream.h>
-#include <values.h>
+#include <limits.h>
 
-#define BITSTRBITS   BITS(short)
+#define BITSTRBITS  (sizeof(short) * CHAR_BIT)
 
 struct BitStrRep
 {
