@@ -26,6 +26,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <std.h>
 #include <Obstack.h>
 #include <AllocRing.h>
+#include <strstream.h>
 
 // default parameters
 
@@ -451,18 +452,29 @@ Fix atoF(const char* a, int len)
 
 extern AllocRing _libgxx_fmtq;
 
+void Fix::printon(ostream& s, int width)
+{
+  char format[20];
+  double val = value(*this);
+  int old_precision = s.precision(width-3);
+  ios::fmtflags old_flags = s.setf(ios::fixed, ios::fixed|ios::scientific);
+  if (val >= 0)
+      s << ' ';
+  s.width(width-2);
+  s << val;
+  s.precision(old_precision);
+  s.flags(old_flags);
+}
+
 char* Ftoa(Fix& x, int width)
 {
   int wrksiz = width + 2;
-  char *s = (char *) _libgxx_fmtq.alloc(wrksiz);
-  char format[100];
-  double val = value(x);
-  if (val < 0)
-    sprintf(format,"%%%d.%dlf",width-2,width-3);
-  else
-    sprintf(format," %%%d.%dlf",width-2,width-3);
-  sprintf(s,format,val);
-  return s;
+  char *fmtbase = (char *) _libgxx_fmtq.alloc(wrksiz);
+  ostrstream stream(fmtbase, wrksiz);
+  
+  x.printon(stream, width);
+  stream << ends;
+  return fmtbase;
 }
 
 extern Obstack _libgxx_io_ob;
@@ -542,7 +554,16 @@ void show(Fix& x)
   cout << "len = " << x.rep->len << "\n";
   cout << "siz = " << x.rep->siz << "\n";
   cout << "ref = " << x.rep->ref << "\n";
-  cout << "man = " << Itoa(mantissa(x),16,4*x.rep->siz) << "\n";
+  cout << "man = ";
+#ifdef _OLD_STREAMS
+  cout << Itoa(mantissa(x),16,4*x.rep->siz);
+#else
+  int old_flags = cout.setf(ios::hex, ios::hex|ios::dec|ios::oct);
+  cout.width(4*x.rep->siz);
+  cout << mantissa(x);
+  cout.setf(old_flags, ios::hex|ios::dec|ios::oct);
+#endif
+  cout << "\n";
   cout << "val = " << value(x) << "\n";
 }
 
