@@ -32,7 +32,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <std.h>
 #include <ctype.h>
 #include <math.h>
-#include <values.h>
+#include <limits.h>
 #include <Obstack.h>
 #include <AllocRing.h>
 #include <new.h>
@@ -44,7 +44,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  as unsigned shorts is changed in the implementation files.
 */
 
-#define I_SHIFT         SHORTBITS
+#define I_SHIFT         (sizeof(short) * CHAR_BIT)
 #define I_RADIX         ((unsigned long)(1L << I_SHIFT))
 #define I_MAXNUM        ((unsigned long)((I_RADIX - 1)))
 #define I_MINNUM        ((unsigned long)(I_RADIX >> 1))
@@ -52,8 +52,8 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #define I_NEGATIVE      0
 
 /* All routines assume SHORT_PER_LONG > 1 */
-#define SHORT_PER_LONG  ((unsigned)(((LONGBITS + SHORTBITS - 1) / SHORTBITS)))
-#define CHAR_PER_LONG   ((unsigned)(((LONGBITS + CHARBITS - 1) / CHARBITS)))
+#define SHORT_PER_LONG  ((unsigned)(((sizeof(long) + sizeof(short) - 1) / sizeof(short))))
+#define CHAR_PER_LONG   ((unsigned)sizeof(long))
 
 /*
   minimum and maximum sizes for an IntRep
@@ -349,7 +349,7 @@ IntRep* Icopy_one(IntRep* old, int newsgn)
 long Itolong(const IntRep* rep)
 { 
   if ((unsigned)(rep->len) > (unsigned)(SHORT_PER_LONG))
-    return (rep->sgn == I_POSITIVE) ? MAXLONG : MINLONG;
+    return (rep->sgn == I_POSITIVE) ? LONG_MAX : LONG_MIN;
   else if (rep->len == 0)
     return 0;
   else if ((unsigned)(rep->len) < (unsigned)(SHORT_PER_LONG))
@@ -366,7 +366,7 @@ long Itolong(const IntRep* rep)
   {
     unsigned long a = rep->s[SHORT_PER_LONG - 1];
     if (a >= I_MINNUM)
-      return (rep->sgn == I_POSITIVE) ? MAXLONG : MINLONG;
+      return (rep->sgn == I_POSITIVE) ? LONG_MAX : LONG_MIN;
     else
     {
       a = up(a) | rep->s[SHORT_PER_LONG - 2];
@@ -381,7 +381,7 @@ long Itolong(const IntRep* rep)
 }
 
 // test whether op long() will work.
-// careful about asymmetry between MINLONG & MAXLONG
+// careful about asymmetry between LONG_MIN & LONG_MAX
 
 int Iislong(const IntRep* rep)
 {
@@ -1806,7 +1806,7 @@ IntRep*  compl(const IntRep* src, IntRep* r)
   return r;
 }
 
-void setbit(Integer& x, long b)
+void (setbit)(Integer& x, long b)
 {
   if (b >= 0)
   {
