@@ -25,7 +25,7 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <String.h>
 #include <std.h>
 #include <ctype.h>
-#include <values.h>
+#include <limits.h>
 #include <new.h>
 #include <builtin.h>
 
@@ -109,7 +109,7 @@ inline static int slen(const char* t) // inline  strlen
 
 // minimum & maximum representable rep size
 
-#define MAXStrRep_SIZE   ((1 << (SHORTBITS - 1)) - 1)
+#define MAXStrRep_SIZE   ((1 << (sizeof(short) * CHAR_BIT - 1)) - 1)
 #define MINStrRep_SIZE   16
 
 #ifndef MALLOC_MIN_OVERHEAD
